=======
waluigi
=======




.. image:: https://pyup.io/repos/github/pwoolvett/waluigi/shield.svg
     :target: https://pyup.io/repos/github/pwoolvett/waluigi/
     :alt: Updates



Opinionated Luigi extensions



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
